ContentPane layout-related DOH test

# dijit/layout/ContentPane layout related DOH test

Tests ContentPane in it's role as a layout widget, including as child of another layout widgets (especially TabContainer).

## Tests that href gets loaded when ContentPane is first made visible

initially selected pane
unselected pane
initially selected inner pane
unselected pane
left pane
center pane

## Tests for resizing in a layout container hierarchy

initially selected pane
hide the second widget to see if ContentPane can still find it
ending text

## Size on Form, single nested layout widget

resizable

## Size on Form, multiple nested widgets

child #1 (100x100)
child #2 (100x100)
visible
resizable

## No size on Form, single nested layout widgets

## No size on Form, multiple nested layout widget

child #1 (100x100)
child #2 (100x100)

## Tests that ContentPane resize doesn't trigger reload

initially selected pane
unselected pane

## Test the ContentPane loads href and resizes children (as per it's contract a layout widget) when it's not a child of a layout container itself